@@ -20,7 +20,8 @@ from appzoo import App
 from appzoo.utils import get_zk_config, cfg
 
 ac_url = cfg['ac_url']
-logos = set(get_zk_config('mipush.ocr')['logos'])
+# cp2flags = get_zk_config('mipush.ocr')
+# cp2flag = sum([list(zip([k] * len(v), v)) for k, v in cp2flags.items()], [])
 
 ocr = PaddleOCR(use_angle_cls=True, lang="ch")
 
@@ -43,12 +44,24 @@ def get_ocr_result(**kwargs):
     return eval(str(results))
 
 
+def text_match_flag(image_result, w, h):
+    cp2flags = get_zk_config('mipush.ocr')
+    for text_loc, (text, _) in image_result:
+        text = text.strip().lower()
+        for cp, flags in cp2flags.items():
+            for flag in flags:
+                if text.__contains__(flag):
+                    text_loc = np.array(text_loc).mean(0)
+                    text_loc_ = text_loc - (w / 2, h / 2)
+                    return cp, text, text_loc_.tolist()
+
+
 def get_water_mark(**kwargs):
     """
     # 负负左上角
     # 正正右下角
-    # 负正右上角
-    # 正负左下角
+    # 正负右上角
+    # 负正左下角
     """
     image_urls = kwargs.get('image_urls', [])
 
@@ -57,15 +70,7 @@ def get_water_mark(**kwargs):
         os.system(f"wget -q {image_url} -O image")
         w, h = Image.open('image').size
         image_result = ocr.ocr('image', cls=True)  # todo
-
-        for text_loc, (text, _) in image_result:
-            text = text.strip().lower()
-            if text in logos:
-                text_loc = np.array(text_loc).mean(0)
-                text_loc_ = text_loc - (w / 2, h / 2)
-                results.append((text, text_loc_.tolist()))
-                break
-
+        results.append(text_match_flag(image_result, w, h))
     return results
 
 
